==> thermoo-8.0.1-sources.jar: com/github/thedeathlycow/thermoo/impl/temperature/effect/TemperatureEffectManager.java <==
package com.github.thedeathlycow.thermoo.impl.temperature.effect;

import com.github.thedeathlycow.thermoo.api.temperature.effects.ConfiguredTemperatureEffect;
import com.github.thedeathlycow.thermoo.impl.Thermoo;
import java.util.*;
import java.util.stream.Collectors;
import net.minecraft.class_1299;
import net.minecraft.class_1309;
import net.minecraft.class_2960;
import net.minecraft.class_5321;
import net.minecraft.class_6880;

public class TemperatureEffectManager {

    public static final TemperatureEffectManager INSTANCE = new TemperatureEffectManager();

    private final Map<class_5321<class_1299<?>>, Set<EntityTypeCacheEntry>> entityTypeCache = new IdentityHashMap<>();

    private final Map<class_2960, ConfiguredTemperatureEffect<?>> registry = new HashMap<>();

    public Set<EntityTypeCacheEntry> getEffectsEntriesForEntity(class_1309 entity) {
        class_1299<?> type = entity.method_5864();

        class_6880.class_6883<class_1299<?>> entityTypeEntry = type.method_40124();
        class_5321<class_1299<?>> entityTypeKey = entityTypeEntry.method_40237();

        Set<EntityTypeCacheEntry> effects = this.entityTypeCache.computeIfAbsent(
                entityTypeKey,
                ignored -> {
                    if (Thermoo.LOGGER.isDebugEnabled()) {
                        Thermoo.LOGGER.debug("Computing temperature effects for {}", entityTypeKey);
                    }
                    return this.registry.entrySet()
                            .stream()
                            .filter(entry -> {
                                var allowedTypes = entry.getValue().entityTypes();
                                return allowedTypes.method_40247() == 0 || type.method_53125(allowedTypes);
                            })
                            .map(EntityTypeCacheEntry::new)
                            .collect(Collectors.toUnmodifiableSet());
                }
        );

        if (Thermoo.LOGGER.isDebugEnabled()) {
            class_2960[] effectIds = effects.stream()
                    .map(entry -> entry.id)
                    .toArray(class_2960[]::new);
            Thermoo.LOGGER.debug("Available Temperature Effects for {}: {}", entityTypeKey, Arrays.toString(effectIds));
        }

        return effects;
    }

    public ConfiguredTemperatureEffect<?> getEffect(class_2960 id) {
        return this.registry.getOrDefault(id, null);
    }

    public Collection<ConfiguredTemperatureEffect<?>> getAllEffects() {
        return this.registry.values();
    }

    public record EntityTypeCacheEntry(class_2960 id, ConfiguredTemperatureEffect<?> effect) {
        public EntityTypeCacheEntry(Map.Entry<class_2960, ConfiguredTemperatureEffect<?>> mapEntry) {
            this(mapEntry.getKey(), mapEntry.getValue());
        }
    }

    void updateRegistry(Map<class_2960, ConfiguredTemperatureEffect<?>> effectsRegistry) {
        this.clearCache();

        this.registry.clear();
        this.registry.putAll(effectsRegistry);

        int numEffects = this.registry.size();
        Thermoo.LOGGER.info("Loaded {} temperature effect{}", numEffects, numEffects == 1 ? "" : "s");
    }

    private void clearCache() {
        this.entityTypeCache.clear();
        Thermoo.LOGGER.info("Clearing Entity Type to Temperature Effect cache");
    }

    private TemperatureEffectManager() {

    }
}

==> thermoo-9.0.0-sources.jar: com/github/thedeathlycow/thermoo/impl/temperature/effect/TemperatureEffectManager.java <==
package com.github.thedeathlycow.thermoo.impl.temperature.effect;

import com.github.thedeathlycow.thermoo.api.temperature.effects.ConfiguredTemperatureEffect;
import com.github.thedeathlycow.thermoo.impl.Thermoo;
import java.util.*;
import java.util.stream.Collectors;
import net.minecraft.class_1299;
import net.minecraft.class_1309;
import net.minecraft.class_2960;
import net.minecraft.class_5321;
import net.minecraft.class_6880;

public class TemperatureEffectManager {

    public static final TemperatureEffectManager INSTANCE = new TemperatureEffectManager();

    private final Map<class_5321<class_1299<?>>, Set<EntityTypeCacheEntry>> entityTypeCache = new IdentityHashMap<>();

    private final Map<class_2960, ConfiguredTemperatureEffect<?>> registry = new HashMap<>();

    public Set<EntityTypeCacheEntry> getEffectsEntriesForEntity(class_1309 entity) {
        class_1299<?> type = entity.method_5864();

        class_6880.class_6883<class_1299<?>> entityTypeEntry = type.method_40124();
        class_5321<class_1299<?>> entityTypeKey = entityTypeEntry.method_40237();

        Set<EntityTypeCacheEntry> effects = this.entityTypeCache.computeIfAbsent(
                entityTypeKey,
                ignored -> {
                    if (Thermoo.LOGGER.isDebugEnabled()) {
                        Thermoo.LOGGER.debug("Computing temperature effects for {}", entityTypeKey);
                    }
                    return this.registry.entrySet()
                            .stream()
                            .filter(entry -> {
                                var allowedTypes = entry.getValue().entityTypes();
                                return allowedTypes.method_40247() == 0 || type.method_53125(allowedTypes);
                            })
                            .map(EntityTypeCacheEntry::new)
                            .collect(Collectors.toUnmodifiableSet());
                }
        );

        if (Thermoo.LOGGER.isDebugEnabled()) {
            class_2960[] effectIds = effects.stream()
                    .map(entry -> entry.location)
                    .toArray(class_2960[]::new);
            Thermoo.LOGGER.debug("Available Temperature Effects for {}: {}", entityTypeKey, Arrays.toString(effectIds));
        }

        return effects;
    }

    public ConfiguredTemperatureEffect<?> getEffect(class_2960 location) {
        return this.registry.getOrDefault(location, null);
    }

    public Collection<ConfiguredTemperatureEffect<?>> getAllEffects() {
        return this.registry.values();
    }

    public record EntityTypeCacheEntry(class_2960 location, ConfiguredTemperatureEffect<?> effect) {
        public EntityTypeCacheEntry(Map.Entry<class_2960, ConfiguredTemperatureEffect<?>> mapEntry) {
            this(mapEntry.getKey(), mapEntry.getValue());
        }
    }

    void updateRegistry(Map<class_2960, ConfiguredTemperatureEffect<?>> effectsRegistry) {
        this.clearCache();

        this.registry.clear();
        this.registry.putAll(effectsRegistry);

        int numEffects = this.registry.size();
        Thermoo.LOGGER.info("Loaded {} temperature effect{}", numEffects, numEffects == 1 ? "" : "s");
    }

    private void clearCache() {
        this.entityTypeCache.clear();
        Thermoo.LOGGER.info("Clearing Entity Type to Temperature Effect cache");
    }

    private TemperatureEffectManager() {

    }
}
